#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyclass
version:              1.0.0.0
visibility:           public
id:                   prettyclass-1.0.0.0-9nU3cEKcLap2CXX0QWUjkF
key:                  prettyclass-1.0.0.0-9nU3cEKcLap2CXX0QWUjkF
license:              BSD-3-Clause
maintainer:           Lennart Augustsson
author:               Lennart Augustsson
stability:            experimental
synopsis:             Pretty printing class similar to Show.
description:
    Pretty printing class similar to Show, based on the HughesPJ
    pretty printing library.  Provides the pretty printing class
    and instances for the Prelude types.

category:             Text
abi:                  e9104158688b9da4128934dc2b8fd372
exposed:              True
exposed-modules:      Text.PrettyPrint.HughesPJClass
import-dirs:          /usr/lib/ghc-8.10.5/site-local/prettyclass-1.0.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/prettyclass-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/prettyclass-1.0.0.0
hs-libraries:         HSprettyclass-1.0.0.0-9nU3cEKcLap2CXX0QWUjkF
depends:              base-4.14.2.0 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-prettyclass/html/prettyclass.haddock
haddock-html:         /usr/share/doc/haskell-prettyclass/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

